@@ -16,6 +16,11 @@ function r = ranks(X,DIM,Mode)
 % r = ranks(X,DIM,'advanced   ')
 %   implements an advanced algorithm with O(n*log(n)) computational 
 %   and O(n.log(n)) memory effort
+% r = ranks(X,DIM,'advanced-ties')
+%   implements an advanced algorithm with O(n*log(n)) computational 
+%   and O(n.log(n)) memory effort
+%   but without correction for ties 
+%   This is the fastest algorithm 
 %
 % see also: CORRCOEF, SPEARMAN, RANKCORR
 %
@@ -23,8 +28,8 @@ function r = ranks(X,DIM,Mode)
 % --
 
 
-%    $Id: ranks.m 8223 2011-04-20 09:16:06Z schloegl $
-%    Copyright (C) 2000-2002,2005,2010 by Alois Schloegl <alois.schloegl@gmail.com>	
+%    $Id: ranks.m 12338 2013-11-11 22:03:45Z schloegl $
+%    Copyright (C) 2000-2002,2005,2010,2013 by Alois Schloegl <alois.schloegl@gmail.com>	
 %    This script is part of the NaN-toolbox
 %       http://pub.ist.ac.at/~schloegl/matlab/NaN/
 
@@ -46,8 +51,8 @@ function r = ranks(X,DIM,Mode)
 % + computational effort is O(n.log(n)) instead of O(n^2)
 % + memory effort is O(n.log(n)), instead of O(n^2). 
 %     Now, the ranks of 8000 elements can be easily calculated
-% + NaN's in the input yield NaN in the output 
-% + compatible with this software and Matlab
+% + NaNs in the input yield NaN in the output 
+% + compatible with Octave and Matlab
 % + traditional method is also implemented for comparison. 
 
 
@@ -62,15 +67,24 @@ if isempty(Mode),
 	Mode='advanced   '; 
 end;
 
-sz = size(X);
+sz_orig = size (X);
+X = squeeze (X); %remove singleton dimensions for convenience
+nd = ndims (X);
 if (~DIM)
-	 DIM = find(sz>1,1);
-end;	 
-[N,M] = size(X);
-if (DIM==2),
-        X = X';
-	[N,M] = size(X);
-end; 
+	 DIM = 1;
+end
+if DIM > 1 %shift the array so that the dimension to sort over is first
+  perm = [DIM 1:(DIM-1) (DIM+1):nd];
+  X = permute (X, perm);
+end
+if nd > 2  %convert X to 2-D if it has >2 dimensions
+  sz = size(X);
+  N = sz(1);
+  M = prod(sz(2:end));
+  X = reshape(X, N, M);
+else
+  [N,M] = size(X);
+end
 
 if strcmp(Mode(1:min(11,length(Mode))),'traditional'), % traditional, needs O(m.n^2)
 % this method was originally implemented by: KH <Kurt.Hornik@ci.tuwien.ac.at>
@@ -83,7 +97,7 @@ r = zeros(size(X));
         end;
         % r(r<1)=NaN;
         
-elseif strcmp(Mode(1:min(12,length(Mode))),'mtraditional'), % advanced
+elseif strcmp(Mode(1:min(12,length(Mode))),'mtraditional'), 
         % + memory effort is lower
         
 	r = zeros(size(X));
@@ -94,7 +108,19 @@ elseif strcmp(Mode(1:min(12,length(Mode))),'mtraditional'), % advanced
         end;
         % r(r<1)=NaN;
         
-elseif strcmp(Mode(1:min(11,length(Mode))),'advanced   '), % advanced
+elseif strcmp(Mode(1:min(13,length(Mode))),'advanced-ties'), % advanced
+        % + uses sorting, hence needs only O(m.n.log(n)) computations         
+        % - does not fix ties
+
+        r = zeros(size(X));
+        [sX, ix] = sort(X,1); 
+	for k=1:M,
+	        [tmp,r(:,k)] = sort(ix(:,k),1);	    % r yields the rank of each element 	
+	end;        
+	r(isnan(X)) = nan;
+
+        
+elseif strcmp(Mode(1:min(8,length(Mode))),'advanced'), % advanced
         % + uses sorting, hence needs only O(m.n.log(n)) computations         
         
         % [tmp,ix] = sort([X,Y]);     
@@ -147,6 +173,27 @@ elseif strcmp(Mode,'=='),
         r(isnan(X)) = nan;
 end;
 
-if (DIM==2)
-	r=r';
-end;	
+%reshape r to match the input X
+if nd > 2
+  r = reshape (r, sz);
+end
+if (DIM > 1)
+	r = ipermute (r, perm);
+end
+r = reshape (r, sz_orig); %restore any singleton dimensions
+
+
+%!shared z, r1, r2
+%! z = magic (4);
+%! r1 = [4   1   1   4; 2   3   3   2; 3   2   2   3; 1   4   4   1];
+%! r2 = [4   1   2   3; 1   4   3   2; 3   2   1   4; 2   3   4   1];
+%!assert (ranks(z), r1);
+%!assert (ranks(z, 2), r2);
+%! z = nan(2, 2, 2);  
+%! z(:, :, 1) = [1 2; 3 4];
+%! z(:, :, 2) = [4 3; 2 1];
+%! r1 = cat(3, [1 1; 2 2], [2 2; 1 1]);
+%! r2 = cat(3, [1 2; 1 2], [2 1; 2 1]);
+%!assert (ranks(z), r1);
+%!assert (ranks(z, 2), r2);
+%!assert (ranks(z, 3), r1);
