@@ -30,7 +30,7 @@ function [R]=test_sc(CC,D,mode,classlabel)
 % [1] R. Duda, P. Hart, and D. Stork, Pattern Classification, second ed. 
 %       John Wiley & Sons, 2001.
 
-%	$Id: test_sc.m 8223 2011-04-20 09:16:06Z schloegl $
+%	$Id: test_sc.m 9601 2012-02-09 14:14:36Z schloegl $
 %	Copyright (C) 2005,2006,2008,2009,2010 by Alois Schloegl <alois.schloegl@gmail.com>
 %       This function is part of the NaN-toolbox
 %       http://pub.ist.ac.at/~schloegl/matlab/NaN/
@@ -47,7 +47,7 @@ function [R]=test_sc(CC,D,mode,classlabel)
 % 
 % You should have received a copy of the GNU General Public License
 % along with this program; if not, write to the Free Software
-% Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+% Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA 02110-1301, USA.
 
 if nargin<3,
         mode = [];
@@ -131,18 +131,13 @@ elseif strcmp(CC.datatype,'classifier:csp')
 
 
 elseif strcmp(CC.datatype,'classifier:svm:lib:1vs1') || strcmp(CC.datatype,'classifier:svm:lib:rbf');
-
-        cl = svmpredict_mex(ones(size(D,1),1), D, CC.model);   %Use the classifier
-
+        nr = size(D,1);
+	[cl] = svmpredict_mex(ones(nr,1), D, CC.model);   %Use the classifier
         %Create a pseudo tsd matrix for bci4eval
-        d = zeros(size(D,1), CC.model.nr_class);
-        for i = 1:size(cl,1)
-                d(i,cl(i)) = 1;
-        end
+	d = full(sparse(1:nr,cl,1,nr,CC.model.nr_class));
 
 
 elseif isfield(CC,'weights'); %strcmpi(t2,'svm') || (strcmpi(t2,'statistical') & strncmpi(t3,'ld',2)) ;
-
         % linear classifiers like: LDA, SVM, LPM 
         %d = [ones(size(D,1),1), D] * CC.weights;
         d = repmat(NaN,size(D,1),size(CC.weights,2));
