@@ -1,6 +1,6 @@
 /*
 
-$Id: train.c 8223 2011-04-20 09:16:06Z schloegl $
+$Id: train.c 12493 2014-01-10 14:18:40Z schloegl $
 Copyright (c) 2007-2009 The LIBLINEAR Project.
 Copyright (c) 2010 Alois Schloegl <alois.schloegl@gmail.com>
 This function is part of the NaN-toolbox
@@ -355,7 +355,7 @@ void mexFunction( int nlhs, mxArray *plhs[],
 		}
 
 		// train's original code
-		error_msg = check_parameter(&prob, &param);
+		error_msg = check_parameter(&param);
 
 		if(err || error_msg)
 		{
