@@ -1,18 +1,21 @@
 //-------------------------------------------------------------------
-//   C-MEX implementation of kth element - this function is part of the NaN-toolbox.
+//   XPTOPEN is C-MEX implementation for reading various  
+//   statistical data formats including SAS/XPT, SPSS/PASW, 
+//   STATA and ARFF data formats. Basic support for writing 
+//   SAS/XPT is also supported. 
+//   Endian conversion is done automatically.
 //
 //   usage: x = xptopen(filename)
 //   usage: x = xptopen(filename,'r')
 //		read filename and return variables in struct x
-
 //   usage: xptopen(filename,'w',x)
 //		save fields of struct x in filename
-
 //   usage: x = xptopen(filename,'a',x)
 //		append fields of struct x to filename
 //
 //   References:
 //
+
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License as published by
 //   the Free Software Foundation; either version 3 of the License, or
@@ -26,8 +29,8 @@
 //   You should have received a copy of the GNU General Public License
 //   along with this program; if not, see <http://www.gnu.org/licenses/>.
 //
-//    $Id: xptopen.cpp 9607 2012-02-10 09:50:15Z schloegl $
-//    Copyright (C) 2010,2011 Alois Schloegl <alois.schloegl@gmail.com>
+//    $Id: xptopen.cpp 12496 2014-01-13 08:47:27Z schloegl $
+//    Copyright (C) 2010,2011,2012,2013 Alois Schloegl <alois.schloegl@ist.ac.at>
 //    This function is part of the NaN-toolbox
 //    http://pub.ist.ac.at/~schloegl/matlab/NaN/
 //
@@ -72,36 +75,102 @@ SPSS file format
 #define max(a,b)	(((a) > (b)) ? (a) : (b))
 #define min(a,b)	(((a) < (b)) ? (a) : (b))
 
-#ifdef __linux__
-/* use byteswap macros from the host system, hopefully optimized ones ;-) */
-#include <byteswap.h>
-#endif
 
-#ifdef _WIN32
-#define __LITTLE_ENDIAN 1234
-#define __BIG_ENDIAN 4321
-#define __BYTE_ORDER __LITTLE_ENDIAN
-#endif
+#if 0
 
-#if (defined(BSD) && (BSD >= 199103))
-#include <machine/endian.h>
-#define __BIG_ENDIAN _BIG_ENDIAN
-#define __LITTLE_ENDIAN _LITTLE_ENDIAN
-#define __BYTE_ORDER _BYTE_ORDER
-#endif
+#elif defined(__linux__)
+#  include <endian.h>
+#  include <byteswap.h>
 
-#ifndef _BYTESWAP_H
-/* define our own version - needed for Max OS X*/
-#define bswap_16(x)   \
+#elif defined(__CYGWIN__)
+#  include <endian.h>
+#  include <byteswap.h>
+
+#elif defined(__GLIBC__)	// for Hurd
+#  include <endian.h>
+#  include <byteswap.h>
+
+#elif defined(__MINGW32__) 
+   /* use local version because MINGW does not provide byteswap.h */
+#  define __BIG_ENDIAN		4321
+#  define __LITTLE_ENDIAN  	1234
+#  define __BYTE_ORDER 		__LITTLE_ENDIAN
+
+#elif defined(__NetBSD__)
+#  include <sys/bswap.h>
+#  define __BIG_ENDIAN _BIG_ENDIAN
+#  define __LITTLE_ENDIAN _LITTLE_ENDIAN
+#  define __BYTE_ORDER _BYTE_ORDER
+#  define bswap_16(x) bswap16(x)
+#  define bswap_32(x) bswap32(x)
+#  define bswap_64(x) bswap64(x)
+
+#elif defined(_APPLE_) && defined(_MACH_)
+#  include <machine/endian.h>
+#  define _BYTE_ORDER __DARWIN_BYTE_ORDER
+#  define _LITTLE_ENDIAN __DARWIN_LITTLE_ENDIAN
+#  define _BIG_ENDIAN __DARWIN_BIG_ENDIAN
+#  define bswap_16(x) __bswap16(x)
+#  define bswap_32(x) __bswap32(x)
+#  define bswap_64(x) __bswap64(x)
+
+#elif defined(__APPLE__)
+#  include <CoreFoundation/CFByteOrder.h>
+#  define __BIG_ENDIAN       4321
+#  define __LITTLE_ENDIAN  1234
+#if (defined(__LITTLE_ENDIAN__) && (__LITTLE_ENDIAN__ == 1))
+    #define __BYTE_ORDER __LITTLE_ENDIAN
+#else
+    #define __BYTE_ORDER __BIG_ENDIAN
+#endif
+#  define bswap_16(x) CFSwapInt16(x)
+#  define bswap_32(x) CFSwapInt32(x)
+#  define bswap_64(x) CFSwapInt64(x)
+
+#elif (defined(BSD) && (BSD >= 199103)) && !defined(__GLIBC__)
+#  include <machine/endian.h>
+#  define __BIG_ENDIAN _BIG_ENDIAN
+#  define __LITTLE_ENDIAN _LITTLE_ENDIAN
+#  define __BYTE_ORDER _BYTE_ORDER
+#  define bswap_16(x) __bswap16(x)
+#  define bswap_32(x) __bswap32(x)
+#  define bswap_64(x) __bswap64(x)
+
+#elif defined(__GNUC__) 
+   /* use byteswap macros from the host system, hopefully optimized ones ;-) */
+#  include <endian.h>
+#  include <byteswap.h>
+#  define bswap_16(x) __bswap_16 (x)
+#  define bswap_32(x) __bswap_32 (x)
+#  define bswap_64(x) __bswap_64 (x)
+
+#elif defined(__sparc__) 
+#  define __BIG_ENDIAN  	4321
+#  define __LITTLE_ENDIAN  	1234
+#  define __BYTE_ORDER 	__BIG_ENDIAN
+
+#else
+#  error Unknown platform
+#endif 
+
+#if defined(__MINGW32__) || defined(__sparc__) 
+
+# ifndef bswap_16
+#  define bswap_16(x)   \
 	((((x) & 0xff00) >> 8) | (((x) & 0x00ff) << 8))
+# endif
 
-#define bswap_32(x)   \
+# ifndef bswap_32
+#  define bswap_32(x)   \
 	 ((((x) & 0xff000000) >> 24) \
         | (((x) & 0x00ff0000) >> 8)  \
 	| (((x) & 0x0000ff00) << 8)  \
 	| (((x) & 0x000000ff) << 24))
 
-#define bswap_64(x) \
+# endif
+
+# ifndef bswap_64
+#  define bswap_64(x) \
       	 ((((x) & 0xff00000000000000ull) >> 56)	\
       	| (((x) & 0x00ff000000000000ull) >> 40)	\
       	| (((x) & 0x0000ff0000000000ull) >> 24)	\
@@ -110,7 +179,14 @@ SPSS file format
       	| (((x) & 0x0000000000ff0000ull) << 24)	\
       	| (((x) & 0x000000000000ff00ull) << 40)	\
       	| (((x) & 0x00000000000000ffull) << 56))
-#endif  /* _BYTESWAP_H */
+# endif
+
+#endif
+
+
+#if !defined(__BIG_ENDIAN) && !defined(__LITTLE_ENDIAN) 
+#error  ENDIANITY is not known 
+#endif 
 
 
 #if __BYTE_ORDER == __BIG_ENDIAN
@@ -769,7 +845,7 @@ if present.
 				size_t maxlen = b_endian_u16(*(int16_t*)(H2+k*sz2+4));
 
 				ListOfVarNames[k] = VarNames+pos;
-				unsigned int n = k*sz2+8;
+				size_t n = k*sz2+8;
 				// int flagDate = (!memcmp(H2+n+48,"DATE    ",8) || !memcmp(H2+n+48,"MONNAME ",8)); // not used
 				do {
 					VarNames[pos++] = H2[n];
@@ -872,7 +948,7 @@ if present.
 		mxArray **F = (mxArray**) mxMalloc(NS*sizeof(mxArray*));
 		char **Fstr = (char**) malloc(NS*sizeof(char*));
 		size_t *MAXLEN = (size_t*) malloc(NS*sizeof(size_t*));
-		for (int16_t k = 0; k < NS; k++) {
+		for (uint16_t k = 0; k < NS; k++) {
 			Fstr[k] = NULL;
 			MAXLEN[k]=0;
 			F[k] = mxGetFieldByNumber(PInputs[2],0,k);
@@ -914,7 +990,7 @@ if present.
 		/* write OBS header line */
 		count += fwrite(LO, 1, strlen(LO), fid);
 		for (mwIndex m = 0; m < M; m++) {
-			for (int16_t k = 0; k < NS; k++) {
+			for (uint16_t k = 0; k < NS; k++) {
 
 				if (*(int16_t*)(H2+k*sz2) == b_endian_u16(1)) {
 					// numeric
@@ -1066,7 +1142,7 @@ double tm_time2gdf_time(struct tm *t) {
 
 	// Set start of year to March by moving Jan. and Feb. to previous year.
   	// Correct for months > 12 by moving to subsequent years.
-  	Y += fix ((M-14.0)/12);
+  	Y += (int)fix ((M-14.0)/12);
 
   	const int monthstart[] = {306, 337, 0, 31, 61, 92, 122, 153, 184, 214, 245, 275};
 	// Lookup number of days since start of the current year.
