@@ -1,6 +1,6 @@
 % TEST_XPTOPEN tests XPTOPEN  
 
-%	$Id: test_xptopen.m 8223 2011-04-20 09:16:06Z schloegl $
+%	$Id: test_xptopen.m 9261 2011-12-04 19:25:51Z schloegl $
 %	Copyright (C) 2010 by Alois Schloegl <alois.schloegl@gmail.com>	
 %       This function is part of the NaN-toolbox
 %       http://biosig-consulting.com/matlab/NaN/
@@ -17,7 +17,7 @@
 % 
 % You should have received a copy of the GNU General Public License
 % along with this program; if not, write to the Free Software
-% Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+% Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA 02110-1301, USA.
 
 %x.c = [-1000,-2,-1,0,1,2,NaN,10,100,1000,10000,1e6,1e7,1e8]';
 %y.Y = [1,2,NaN,1]'+10;
@@ -37,7 +37,7 @@ end;
 fn = {'buy','humid','prdsale'};
 for k1 = 1:length(fn);
 	X = xptopen(fn{k1},'r');
-%	xptopen([fn{k1},'.xpt'],'w',X);
+	xptopen([fn{k1},'.xpt'],'w',X);
 	f = fieldnames(X);
 
 	fid = fopen([fn{k1},'.csv'],'w');
